/*+********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * *********************************************************************************
 * $Header:  \modules\RecycleBin\language\hu_hu.lang.js - 12:11 2011.11.12. $
 * Description:  Defines the Hungarian language pack for the RecycleBin module vtiger 5.3.x
 *
 * Contributor(s): Istvan Holbok,  e-mail: holbok@gmail.com , mobil: +3670-3420900 , Skype: holboki
 ********************************************************************************/

var mod_alert_arr = {
	'SELECT_ATLEAST_ONE_ENTITY' : 'Kérjük, válasszon legalább egy személy',
	'MSG_RESTORE_CONFIRMATION' : 'Biztos benne, hogy vissza akarja állítani a kiválasztott'
};
